@@ -12,15 +12,12 @@
 
 #include "alarmtimewidget.h"
 #include "deferdlg.h"
-#include "functions.h"
 #include "kalarmapp.h"
 #include "latecancel.h"
-#include "mainwindow.h"
 #include "preferences.h"
 #include "recurrenceedit.h"
 #include "reminder.h"
 #include "resourcescalendar.h"
-#include "resources/datamodel.h"
 #include "resources/resources.h"
 #include "lib/autoqpointer.h"
 #include "lib/buttongroup.h"
@@ -30,18 +27,19 @@
 #include "lib/messagebox.h"
 #include "lib/packedlayout.h"
 #include "lib/radiobutton.h"
-#include "lib/shellprocess.h"
-#include "lib/spinbox.h"
 #include "lib/stackedwidgets.h"
 #include "templatepickdlg.h"
 #include "lib/timeedit.h"
 #include "lib/timespinbox.h"
+#include "config-kalarm.h"
 #include "kalarm_debug.h"
 
 #include <KLocalizedString>
 #include <KConfig>
 #include <KSharedConfig>
-#include <KWindowSystem>
+#if ENABLE_X11
+#include <KX11Extras>
+#endif
 
 #include <QLabel>
 #include <QGroupBox>
@@ -423,11 +421,13 @@ void EditAlarmDlg::init(const KAEvent& event)
         contentsChanged();    // enable/disable OK button
     }
 
-    // Note the current desktop so that the dialog can be shown on it.
+    // Note the current virtual desktop so that the dialog can be shown on it.
     // If a main window is visible, the dialog will by KDE default always appear on its
     // desktop. If the user invokes the dialog via the system tray on a different desktop,
     // that can cause confusion.
-    mDesktop = KWindowSystem::currentDesktop();
+#if ENABLE_X11
+    mDesktop = KX11Extras::currentDesktop();
+#endif
 
     if (theApp()->windowFocusBroken())
     {
@@ -846,7 +846,9 @@ void EditAlarmDlg::showEvent(QShowEvent* se)
         }
     }
     slotResize();
-    KWindowSystem::setOnDesktop(winId(), mDesktop);    // ensure it displays on the desktop expected by the user
+#if ENABLE_X11
+    KX11Extras::setOnDesktop(winId(), mDesktop);    // ensure it displays on the virtual desktop expected by the user
+#endif
 
     if (theApp()->needWindowFocusFix())
     {
@@ -992,8 +994,9 @@ bool EditAlarmDlg::validate()
     }
     else if (mTimeWidget)
     {
+        int timeFromNow;
         QWidget* errWidget;
-        mAlarmDateTime = mTimeWidget->getDateTime(nullptr, !timedRecurrence, false, &errWidget);
+        mAlarmDateTime = mTimeWidget->getDateTime(&timeFromNow, !timedRecurrence, false, &errWidget);
         if (errWidget)
         {
             // It's more than just an existing deferral being changed, so the time matters
@@ -1002,6 +1005,15 @@ bool EditAlarmDlg::validate()
             mTimeWidget->getDateTime();   // display the error message now
             return false;
         }
+        if (timeFromNow < 10)
+        {
+            if (KAMessageBox::warningContinueCancel(this, xi18nc("@info", "<para>KAlarm does not provide high accuracy alarms.</para><para> The alarm will trigger at the minute boundary before the specified time from now.</para>"), QString(), KStandardGuiItem::cont(), KStandardGuiItem::cancel(), QStringLiteral("HighAccuracy"))
+                    != KMessageBox::Continue)
+            {
+                mTimeWidget->setFocus();
+                return false;
+            }
+        }
     }
     if (!type_validate(false))
         return false;
